#
# spec file for package kiwi-boot-descriptions
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%if 0%{?fedora}
%global debug_package %{nil}
%endif

# translate version id to distribution name
# generic approach
%if 0%{?suse_version}
%define distro %(echo `export VER=%{suse_version}; echo "suse-${VER:0:2}.${VER:2:1}"`)
%endif

# SLE12:
%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
%define distro suse-SLES12
%endif

# SLE15:
%if 0%{?suse_version} == 1500 && !0%{?is_opensuse}
%define distro suse-SLES15
%endif

# Leap 42.1(openSUSE product based on SLE 12SP1):
%if 0%{?is_opensuse} && 0%{?sle_version} == 120100
%define distro suse-leap42.1
%endif

# Leap 42.2:
%if 0%{?is_opensuse} && 0%{?sle_version} == 120200
%define distro suse-leap42.2
%endif

# Leap 42.3:
%if 0%{?is_opensuse} && 0%{?sle_version} == 120300
%define distro suse-leap42.3
%endif

# Leap 15.0:
%if 0%{?is_opensuse} && 0%{?sle_version} == 150000
%define distro suse-leap15.0
%endif

# Leap 15.1:
%if 0%{?is_opensuse} && 0%{?sle_version} == 150100
%define distro suse-leap15.1
%endif

# Leap 15.2:
%if 0%{?is_opensuse} && 0%{?sle_version} == 150200
%define distro suse-leap15.2
%endif

# Leap 15.3:
%if 0%{?is_opensuse} && 0%{?sle_version} == 150300
%define distro suse-leap15.3
%endif

# Tumbleweed:
# Current Tumbleweed version, moving target
%if 0%{?suse_version} >= 1330 && !0%{?sle_version}
%define distro suse-tumbleweed
%endif

# RHEL // CentOS
# use the rhel templates for CentOS, too
%if 0%{?rhel} == 7
%define distro rhel-07.0
%endif

# Fedora
# use the rhel templates for CentOS, too
%if 0%{?fedora} >= 25
%define distro fedora-25.0
%endif

Name:           kiwi-boot-descriptions
Version:        1.2.0
Release:        lp152.1.1
Url:            https://github.com/SUSE/kiwi-descriptions
Summary:        KIWI - Custom Boot Descriptions
License:        GPL-3.0-or-later
Group:          System/Management
Source:         %{name}.tar.gz
Source1:        kiwi-boot-packages
Source2:        %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?fedora} || 0%{?suse_version}
BuildRequires:  fdupes
%endif
%if 0%{?fedora} || 0%{?rhel}
BuildRequires:  gettext
%endif
%if 0%{?suse_version}
BuildRequires:  gettext-runtime
%endif

%description
Custom KIWI boot descriptions. Before KIWI switched to dracut
as initrd system, the initrd was build from extra image descriptions.
The collection of those image descriptions is available for
convenience and compatibility reasons. Also creating meta sub packages
for the buildservice to allow inclusion of tools into the worker
which are needed to build a specific image type

%if 0%{?suse_version}
%package -n kiwi-boot-requires
Summary:        KIWI - buildservice package requirements for boot images
Group:          System/Management
Provides:       kiwi-boot:netboot
Provides:       kiwi-boot:oemboot
Requires:       kiwi-boot-descriptions
%if !0%{?is_opensuse} || 0%{?sle_version} < 150200
Requires:       %(echo `cat %{S:1}|grep %{_target_cpu}:%{distro}:|cut -f3- -d:`)
%endif

%description -n kiwi-boot-requires
Meta package for the buildservice to pull in all required packages in
order to have them in the buildservice created repositories to allow
kiwi to build the custom boot image.
%endif

%package -n kiwi-image-docker-requires
Summary:        KIWI - buildservice host requirements for docker images
Group:          System/Management
Provides:       kiwi-image:docker
Requires:       jing
Requires:       skopeo
Requires:       umoci

%description -n kiwi-image-docker-requires
Meta package for the buildservice to pull in all required packages
for the build host to build docker images

%package -n kiwi-image-iso-requires
Summary:        KIWI - buildservice host requirements for iso images
Group:          System/Management
Provides:       kiwi-image:iso
Requires:       checkmedia
Requires:       dosfstools
Requires:       jing
%if 0%{?suse_version} >= 1500
Requires:       mkisofs
%else
Requires:       genisoimage
%endif
%ifarch %{ix86} x86_64
Requires:       syslinux
%endif
%description -n kiwi-image-iso-requires
Meta package for the buildservice to pull in all required packages
for the build host to build live iso images

%package -n kiwi-image-oem-requires
Summary:        KIWI - buildservice host requirements for oem images
Group:          System/Management
Provides:       kiwi-image:oem
Requires:       jing
Requires:       kiwi-filesystem-requires
%ifarch %{ix86} x86_64
Requires:       syslinux
%endif
%description -n kiwi-image-oem-requires
Meta package for the buildservice to pull in all required packages
for the build host to build oem disk images

%package -n kiwi-image-pxe-requires
Summary:        KIWI - buildservice host requirements for pxe images
Group:          System/Management
Provides:       kiwi-image:pxe
Requires:       jing
Requires:       kiwi-filesystem-requires

%description -n kiwi-image-pxe-requires
Meta package for the buildservice to pull in all required packages
for the build host to build pxe images

%package -n kiwi-image-vmx-requires
Summary:        KIWI - buildservice host requirements for vmx images
Group:          System/Management
Provides:       kiwi-image:vmx
Requires:       jing
Requires:       kiwi-filesystem-requires

%description -n kiwi-image-vmx-requires
Meta package for the buildservice to pull in all required packages
for the build host to build simple disk images

%package -n kiwi-image-tbz-requires
Summary:        KIWI - buildservice host requirements for root archive tarball
Group:          System/Management
Provides:       kiwi-image:tbz
Requires:       jing
Requires:       tar
Requires:       xz

%description -n kiwi-image-tbz-requires
Meta package for the buildservice to pull in all required packages
for the build host to build root archive tarball

%package -n kiwi-filesystem-requires
Summary:        KIWI - buildservice host requirements for filesystems
Group:          System/Management
Provides:       kiwi-filesystem:btrfs
Provides:       kiwi-filesystem:ext3
Provides:       kiwi-filesystem:ext4
Provides:       kiwi-filesystem:squashfs
Provides:       kiwi-filesystem:xfs
Requires:       e2fsprogs
Requires:       jing
Requires:       xfsprogs
%if 0%{?fedora} || 0%{?rhel}
Requires:       btrfs-progs
Requires:       squashfs-tools
%else
Requires:       btrfsprogs
Requires:       squashfs
%endif
%description -n kiwi-filesystem-requires
Meta package for the buildservice to pull in a collection of
filesystem packages for the build host to support the most common
used filesystems for images

%prep
%setup -q -n custom_boot

%build

%install
make buildroot=%{buildroot} install 

%if 0%{?fedora} || 0%{?suse_version}
%fdupes %{buildroot}/%{_datadir}/kiwi/custom_boot
%endif

%files -n kiwi-boot-descriptions
%defattr(-, root, root)
%dir %{_datadir}/kiwi
%{_datadir}/kiwi/custom_boot

%if 0%{?suse_version}
%files -n kiwi-boot-requires
%defattr(-, root, root)
%endif

%files -n kiwi-image-docker-requires
%defattr(-, root, root)

%files -n kiwi-image-iso-requires
%defattr(-, root, root)

%files -n kiwi-image-oem-requires
%defattr(-, root, root)

%files -n kiwi-image-pxe-requires
%defattr(-, root, root)

%files -n kiwi-image-vmx-requires
%defattr(-, root, root)

%files -n kiwi-image-tbz-requires
%defattr(-, root, root)

%files -n kiwi-filesystem-requires
%defattr(-, root, root)

%changelog
* Wed Oct 16 2019 Marcus Schaefer <ms@suse.com>
- Fixed ISO Application ID match
  When creating ISO's with xorriso the application ID is stored
  upper case. The match in this code did not care for this and
  failed the match.
* Thu Sep 12 2019 David Cassany <dcassany@suse.com>
- Drop netboot descriptions for openSUSE Leap 15.2
  This commit drops support for netboot descriptions for openSUSE Leap 15.2
  or higher.
  More specific, this commit removes the tool chain requirements of
  kiwi-boot-requires for Leap 15.2 or higher. This results on
  kiwi-boot-descriptions being present and installable but not containing
  any Leap 15.2 description, just SLE descriptions and older Leap ones.
  Additionally this commit also removes the Leap 42.2 and Leap 42.3
  descriptions those distros are no longer supported.
  Fixes bsc#1145724
* Tue Aug 20 2019 Marcus Schaefer <ms@suse.com>
- Make application ID check in searchImageISODevice() case-insensitive
* Mon Jul 29 2019 Marcus Schaefer <ms@suse.com>
- Use %%suse_version instead of %%sle_version do detect SLE 15 (SP*)
  %%sle_version is different depending on SP1 vs GA, but %%suse_version
  is the same for all SLE 15.
* Wed Jul 24 2019 Marcus Schaefer <ms@suse.com>
- modify 'dn' to avoid mangling /dev/sdp block names
* Fri Jul 19 2019 ms@suse.com
- Improve partition validation for PXE
  This commit includes a patch to relax the partition
  size validation. It turned to happen that under some
  specific partition size configurations in the PXE client
  the partition layout was always seen as an invalid one
  in each boot. This was causing a repartition and redeploy
  of the PXE image in every single boot.
  Fixes bsc#1141156
* Fri Jul 19 2019 ms@suse.com
- Normalize partedGetPartitionID output (bsc#1136744)
  This commit ensures the partedGetPartitionID output returns the
  same partition ID codes with or without the presence of sgdisk
  utility. It basically trusts partition names provided by KIWI to map
  partitions to specific IDs.
  Additionally this commit also makes sure that the partition stated
  to be of `ef` type in config.<mac> is named `legacy`, to be consistent
  with the partedGetPartitionID expectations.
* Mon Jul  8 2019 ms@suse.com
- Deleted obsolete boot image descriptions
  The support for dracut in kiwi has settled some time ago and
  for the custom boot descriptions deleted here there is a dracut
  based replacement. See the following list and the reason for
  the deletion:
  * arm/oemboot
    Any oem image created with kiwi-ng for arm uses dracut.
    There is no tested support for oemboot on arm
  * ppc/netboot and ppc/oemboot
    Support for ppc with kiwi-ng is still being worked on.
    We will not support custom oem code when we can have
    dracut based support. This obsolete descriptions are an
    artifact of the legacy kiwi version
  * s390/oemboot
    Any oem image created with kiwi-ng for s390 uses dracut
    There is no tested support for oemboot on s390
  * x86_64/oemboot/rhel-07.0 and x86_64/oemboot/ubuntu-xenial
    Obsolete and replaced with generic dracut support in kiwi-ng
  * x86_64/oemboot/suse-leap42.2 and x86_64/oemboot/suse-leap42.3
    Distributions out of support per upstream kiwi policy
  * x86_64/oemboot/suse-tumbleweed
    Lots of changes on the udev and systemd side made oemboot
    non functional anyway. The switch to dracut is inevitable here.
    Thus no reason to keep broken oemboot code around
* Mon Jun 17 2019 ms@suse.com
- Use default values for nr_inode on devtmpfs mounts
  Using nr_inode=0 is causing mount failures in recent kernels. This
  option was introduced to fix issues in split systems, which are no
  longer supported. According to that we just remove this option and
  let mount set the default value, which depends on available memory
  of the system. Fixes SUSE/kiwi#1105
* Thu May 23 2019 ms@suse.com
- Allow disabling multipath
* Wed May 22 2019 ms@suse.com
- Fixed udev startup
  Due to a change in the udev rules an error in kiwi was triggered
  that outlines an incomplete udev startup sequence. This
  patch fixes the creation of the dev tree by udev and is
  related to bsc#1135762
* Wed May 22 2019 ms@suse.com
- Set SERVER variable as expected by netboot code (#674)
  This commit sets $host from $SERVER variable if present and no
  $kiwiserver is given from the command line.
  The same criteria applies for $type and $SERVERTYPE variables.
  Fixes bsc#1133537
* Wed Apr 24 2019 David Cassany <dcassany@suse.com>
- Added netboot definitions for Leap 15.1 (boo#1132839)
* Wed Mar  6 2019 ms@suse.com
- custom_boot/functions.sh: add support for PLABEL in config
* Wed Mar  6 2019 ms@suse.com
- Update spec file:
  * syslinux is only available on x86*, so requires it only for x86
  * Run format spec file
* Mon Jan  7 2019 ms@suse.com
- Fallback to sulogin if setctsid is missing
* Mon Jan  7 2019 ms@suse.com
- Use setctsid/bash instead of sulogin for debugging
  The custom kiwi boot descriptions supports a boot process
  accompanying debug shell if the kiwidebug=1 option is
  set on the kernel command line. That shell was invoked
  using sulogin. Problem is that this call occupies the
  controlling terminal and console such that the typical
  multiplexing of consoles through plymouth is stopped.
  This means it's not possible to run e.g an oem deployment
  with several active/multiplexed consoles and a backgrounding
  debuging shell. This patch moves away from sulogin and
  calls a bash through setctsid on a free console
* Mon Dec 17 2018 ms@suse.com
- Fixed console multiplexer when dialogs get displayed.
  https://github.com/SUSE/kiwi-descriptions/pull/30
* Fri Sep 28 2018 David Cassany <dcassany@suse.com>
- Added syslinux requirement for kiwi-image-iso-requires, this
  fixes bnc#1103398
* Thu Sep 20 2018 ms@suse.com
- Setup swap space with a label in any case
  Independently of the device persistency setup we create
  the swap space with the label named SWAP and add it as
  such to the fstab file
* Mon Aug 13 2018 ms@suse.com
- Clear the terminal I/O before dialog
  Call the reset program to clear the terminal I/O
  prior to call the dialog program. This Fixes bsc#1095856
* Mon May 28 2018 ms@suse.com
- Make sure root entry in fstab is created for pxe
  On pxe deployment via netboot the root entry in fstab was
  not created even if the client config file contains a DISK
  setup
* Wed Apr  4 2018 ms@suse.com
- Add kiwi-image-tbz-requires to provide kiwi-image:tbz
* Tue Mar 13 2018 ms@suse.com
- Added jing as required package in the *-requires sub packages
* Tue Feb 20 2018 ms@suse.com
- Update meta packages structure for the buildservice
* Tue Feb  6 2018 ms@suse.de
- Move of kiwi boot descriptions to its own package
